#!/bin/sh
set -e

# Find uncertainty (position x momentum) for wells of varying width
#
# This script is part of the QWWAD software suite. Any use of this code
# or its derivatives in published work must be accompanied by a citation
# of:
#   P. Harrison and A. Valavanis, Quantum Wells, Wires and Dots, 4th ed.
#    Chichester, U.K.: J. Wiley, 2016, ch.3
#
# (c) Copyright 1996-2016
#     Alex Valavanis <a.valavanis@leeds.ac.uk>
#
# QWWAD is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# QWWAD is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with QWWAD.  If not, see <http://www.gnu.org/licenses/>.

# Initialise files
outfile=uncertainty-principle-finite-well.dat
rm -f $outfile

# Loop for different well widths
for LW in 20 30 40 50 60 70 80 90 100 120 140 160 180 200; do

 # Calculate ground state energy and wave function as a function 
 # of well width for GaAs
 qwwad_ef_square_well --wellwidth $LW

 # Search for line in standard output from hup and write to file 
 data=`qwwad_uncertainty | awk '/Delta_z.Delta_p/{printf("%8.3f\n",$2)}'`

 printf "%d\t%s\n" $LW $data >> $outfile
done

cat << EOF
Results have been written to $outfile in the format:

  COLUMN 1 - Well width [angstrom]
  COLUMN 2 - Uncertainty [x hbar/(2 pi)]

This script is part of the QWWAD software suite.

(c) Copyright 1996-2016
    Alex Valavanis <a.valavanis@leeds.ac.uk>
    Paul Harrison  <p.harrison@leeds.ac.uk>

Report bugs to https://bugs.launchpad.net/qwwad
EOF

# Clean up workspace
rm -f *.r
